# Uaromanizer
Provides means for romanization of Ukrainian writing(barely)

***Installation:***
`pip install uaromanizer`

***Usage:***
`from uaromanizer import Romanizer`
`Romanizer(<cyrillic_ukrainian_writing>).romanize()` -> str
